@@ -139,12 +139,7 @@ class DataFrame:
     _alias: str
 
     def __init__(
-        self,
-        query: str,
-        alias: Optional[str],
-        bigquery: "BigQueryBuilder",
-        deps: Optional[List["DataFrame"]] = None,
-        _ignore_debug: bool = False,
+        self, query: str, alias: Optional[str], bigquery: "BigQueryBuilder", deps: Optional[List["DataFrame"]] = None
     ):
         self.query = query
         if deps is None:
@@ -158,14 +153,14 @@ class DataFrame:
         self._alias = alias
         self.bigquery: "BigQueryBuilder" = bigquery
         self._schema: Optional[List[SchemaField]] = None
-        if self.bigquery.debug and not _ignore_debug:
+        if self.bigquery.debug:
             self.__validate()
 
-    def __validate(self):
+    def __validate(self) -> None:
         """Compiles this :class:`DataFrame's` SQL and send it to BigQuery to validate that the query is correct.
         Used in debug mode.
         """
-        self.bigquery._execute_query(self.limit(0, _ignore_debug=True).compile(), use_query_cache=False)
+        self.bigquery._get_query_schema(self.compile())
 
     def __repr__(self):
         return f"""DataFrame('{self.query}) as {self._alias}')"""
@@ -218,16 +213,13 @@ class DataFrame:
         else:
             raise TypeError("unexpected item type: %s" % type(item))
 
-    def _apply_query(
-        self, query: str, deps: Optional[List["DataFrame"]] = None, _ignore_debug: bool = False
-    ) -> "DataFrame":
+    def _apply_query(self, query: str, deps: Optional[List["DataFrame"]] = None) -> "DataFrame":
         if deps is None:
             deps = [self]
-        return DataFrame(query, None, self.bigquery, deps=deps, _ignore_debug=_ignore_debug)
+        return DataFrame(query, None, self.bigquery, deps=deps)
 
-    def _compute_schema(self):
-        df = self.limit(0)
-        return df.bigquery._execute_query(df.compile(), use_query_cache=False).schema
+    def _compute_schema(self) -> List[SchemaField]:
+        return self.bigquery._get_query_schema(self.compile())
 
     def _compile_deps(self) -> Dict[str, str]:
         return {
@@ -586,10 +578,10 @@ class DataFrame:
         )
         return self._apply_query(query, deps=[self, other])
 
-    def limit(self, num: int, _ignore_debug: bool = False) -> "DataFrame":
+    def limit(self, num: int) -> "DataFrame":
         """Returns a new :class:`DataFrame` with a result count limited to the specified number of rows."""
         query = f"""SELECT * FROM {quote(self._alias)} LIMIT {num}"""
-        return self._apply_query(query, _ignore_debug=_ignore_debug)
+        return self._apply_query(query)
 
     def persist(self) -> "DataFrame":
         """Persist the contents of the :class:`DataFrame` in a temporary table and returns a new DataFrame reading
