@@ -92,6 +92,77 @@ def array(*cols: Union[StringOrColumn, Sequence[StringOrColumn]]) -> Column:
     return Column(f"[{cols_to_str(str_cols)}]")
 
 
+def array_agg(
+    col: StringOrColumn,
+    order_by: Optional[StringOrColumn] = None,
+    distinct: bool = False,
+    ignore_nulls: bool = False,
+    limit: Optional[int] = None,
+) -> Column:
+    """
+    Aggregates this column into an array of values.
+
+
+    Examples
+    --------
+    >>> bq = BigQueryBuilder()
+    >>> from bigquery_frame import functions as f
+    >>> df = bq.sql("SELECT * FROM UNNEST([1, 2, 3, 2, 3, 3]) as c")
+    >>> df.select(f.array_agg("c").alias("a")).show()
+    +--------------------+
+    |                  a |
+    +--------------------+
+    | [1, 2, 3, 2, 3, 3] |
+    +--------------------+
+    >>> df.select(f.array_agg("c", order_by=f.desc("c")).alias("a")).show()
+    +--------------------+
+    |                  a |
+    +--------------------+
+    | [3, 3, 3, 2, 2, 1] |
+    +--------------------+
+    >>> df.select(f.array_agg("c", order_by=f.desc("c"), limit=3).alias("a")).show()
+    +-----------+
+    |         a |
+    +-----------+
+    | [3, 3, 3] |
+    +-----------+
+    >>> df.select(f.array_agg("c", order_by="c", distinct=True).alias("a")).show()
+    +-----------+
+    |         a |
+    +-----------+
+    | [1, 2, 3] |
+    +-----------+
+    >>> null_if_even = f.when(f.col("c") % 2 == 0, f.lit(None)).otherwise(f.col("c"))
+    >>> df.select(f.array_agg(null_if_even, order_by="c", ignore_nulls=True).alias("a")).show()
+    +--------------+
+    |            a |
+    +--------------+
+    | [1, 3, 3, 3] |
+    +--------------+
+
+    :param col: a str (column name) or :class:`Column`
+    :param order_by: (optional) sort the resulting array according to this column
+    :param distinct: (optional) only keep distinct values in the resulting array
+    :param ignore_nulls: (optional) remove null values from the resulting array
+    :param limit: (optional) only keep this number of values in the resulting array
+    :return:
+    """
+    distinct_str = ""
+    ignore_nulls_str = ""
+    limit_str = ""
+    order_by_str = ""
+    if distinct:
+        distinct_str = "DISTINCT "
+    if ignore_nulls:
+        ignore_nulls_str = " IGNORE NULLS "
+    if limit:
+        limit_str = f" LIMIT {limit}"
+    if order_by is not None:
+        order_by_str = f" ORDER BY {str_to_col(order_by).expr}"
+    col_str = str_to_col(col).expr
+    return Column(f"ARRAY_AGG({distinct_str}{col_str}{ignore_nulls_str}{order_by_str}{limit_str})")
+
+
 def asc(col: StringOrColumn) -> Column:
     """Returns a sort expression based on the ascending order of the given column.
 
@@ -307,6 +378,62 @@ def expr(expr: str) -> Column:
     return Column(expr)
 
 
+def from_base32(col: StringOrColumn) -> Column:
+    """Converts the base32-encoded input string_expr into BYTES format.
+    To convert BYTES to a base32-encoded STRING, use :func:`to_base32`.
+
+    Examples
+    --------
+    >>> bq = BigQueryBuilder()
+    >>> from bigquery_frame import functions as f
+    >>> df = bq.sql(r"SELECT 'MFRGGZDF74======' as s")
+    >>> df.select(f.from_base32('s').alias('byte_data')).show()
+    +--------------+
+    |    byte_data |
+    +--------------+
+    | b'abcde\xff' |
+    +--------------+
+
+    """
+    return _invoke_function_over_column("FROM_BASE32", col)
+
+
+def from_base64(col: StringOrColumn) -> Column:
+    """Converts the base64-encoded input string_expr into BYTES format.
+    To convert BYTES to a base64-encoded STRING, use :func:`to_base64`.
+
+    There are several base64 encodings in common use that vary in exactly which alphabet of 65 ASCII characters
+    are used to encode the 64 digits and padding. See RFC 4648 for details.
+    This function expects the alphabet [A-Za-z0-9+/=].
+
+    Examples
+    --------
+    >>> bq = BigQueryBuilder()
+    >>> from bigquery_frame import functions as f
+    >>> df = bq.sql(r"SELECT '/+A=' as s")
+    >>> df.select(f.from_base64('s').alias('byte_data')).show()
+    +-------------+
+    |   byte_data |
+    +-------------+
+    | b'\xff\xe0' |
+    +-------------+
+
+    To work with an encoding using a different base64 alphabet, you might need to compose :func:`from_base64` with
+    the :func:`replace` function. For instance, the base64url url-safe and filename-safe encoding commonly used
+    in web programming uses `-_=` as the last characters rather than `+/=`.
+    To decode a base64url-encoded string, replace `-` and `_` with `+` and `/` respectively.
+
+    >>> df.select(f.from_base64(f.replace(f.replace(f.lit('_-A='), '-', '+'),  '_', '/')).alias('binary')).show()
+    +-------------+
+    |      binary |
+    +-------------+
+    | b'\xff\xe0' |
+    +-------------+
+
+    """
+    return _invoke_function_over_column("FROM_BASE64", col)
+
+
 def hash(*cols: Union[str, Column]) -> Column:
     """Calculates the hash code of given columns, and returns the result as an int column.
 
@@ -658,9 +785,9 @@ def to_base64(col: StringOrColumn) -> Column:
     |          /+A= |
     +---------------+
 
-    To work with an encoding using a different base64 alphabet, you might need to compose TO_BASE64 with the
-    REPLACE function. For instance, the base64url url-safe and filename-safe encoding commonly used in web programming
-    uses -_= as the last characters rather than +/=. To encode a base64url-encoded string,
+    To work with an encoding using a different base64 alphabet, you might need to compose :func:`to_base64` with the
+    :func:`replace` function. For instance, the base64url url-safe and filename-safe encoding commonly used in
+    web programming uses -_= as the last characters rather than +/=. To encode a base64url-encoded string,
     replace + and / with - and _ respectively.
 
     >>> df.select(f.replace(f.replace(f.to_base64('b'), '+', '-'), '/', '_').alias('websafe_base64')).show()
