@@ -6,7 +6,7 @@ from bigquery_frame.column import Column
 
 def _to_string(col: Column, field_type: str):
     if field_type == "BYTES":
-        return f.expr(f"TO_BASE64({col.expr})")
+        return f.to_base64(col)
     else:
         return col.cast("STRING")
 
@@ -44,5 +44,5 @@ def max(col: str, schema_field: SchemaField, col_num: int) -> Column:  # NOSONAR
 
 
 def approx_top_100(col: str, schema_field: SchemaField, col_num: int) -> Column:  # NOSONAR
-    col = f.coalesce(_to_string(f.col(col), schema_field.field_type), f.lit("NULL"))
-    return f.expr(f"APPROX_TOP_COUNT({col.expr}, 100)").alias("approx_top_100")
+    column = f.coalesce(_to_string(f.col(col), schema_field.field_type), f.lit("NULL"))
+    return f.expr(f"APPROX_TOP_COUNT({column.expr}, 100)").alias("approx_top_100")
